@@ -24,18 +24,15 @@ import os
 import sys
 
 from .models import (load_model, quantize, dump_config, save_weights, load_weights,
-                     check_quantization)
-from .models.transforms import fold_rescaling
+                     check_quantization, insert_rescaling)
 
 
-def quantize_model(model_path, quant_config, fold=True, add_deq=True, output_name=None):
+def quantize_model(model_path, quant_config, add_deq=True, output_name=None):
     """ CLI entry point to quantize a model using the provided configuration.
 
     Args:
         model_path (str): Path to the model to quantize.
         quant_config (str): Path to the quantization configuration file.
-        fold (bool, optional): Whether to collapse foldable layers before quantizing.
-            Defaults to True.
         add_deq (bool, optional): allows to convert output to float. Defaults to True.
         output_name (str, optional): name of the output quantized model. If none provided
             set a default name as <model>_<config>.h5. Defaults to None.
@@ -51,11 +48,6 @@ def quantize_model(model_path, quant_config, fold=True, add_deq=True, output_nam
         config = json.load(f)
     model = load_model(model_path)
 
-    # Fold layers
-    if fold:
-        print(f"Collapsing foldable layers of {model_path}.")
-        model = fold_rescaling(model)
-
     # Quantize the model and save it
     print(f"Quantizing model {model_path} with configuration file {quant_config}.")
     model_q = quantize(model, config, add_deq)
@@ -129,6 +121,20 @@ def check_quantized_model(model_path):
         print(msg)
 
 
+def insert_rescaling_and_save(model_path, dest_path, scale, offset):
+    """ CLI entry point to insert a Rescaling layer in a model.
+
+    Args:
+        model_path (str): Path to the source model.
+        dest_path (str): Path to the destination model.
+        scale (float): the Rescaling scale
+        offset (float): the Rescaling offset
+    """
+    model = load_model(model_path)
+    updated = insert_rescaling(model, scale, offset)
+    updated.save(dest_path)
+
+
 def main():
     """ CLI entry point.
 
@@ -146,8 +152,6 @@ def main():
     q_parser.add_argument("-m", "--model", type=str, required=True, help="Model to quantize")
     q_parser.add_argument("-c", "--quantization_config", type=str,
                           required=True, help="Quantization configuration file")
-    q_parser.add_argument("-f", "--fold", action="store_true",
-                          help="Collapse foldable layers before quantizing")
     q_parser.add_argument("-nd", "--no_deq", action="store_false",
                           help="Do not add a dequantizer after head")
     q_parser.add_argument("-o", "--out_name", type=str,
@@ -180,6 +184,18 @@ def main():
         "by adjusting the quantization configuration.")
     c_parser.add_argument("-m", "--model", type=str, required=True, help="Model to check")
 
+    # insert_rescaling action and arguments
+    ir_parser = sp.add_parser(
+        "insert_rescaling", help="Insert a Rescaling layer at the beginning of the Model.")
+    ir_parser.add_argument("-m", "--model", type=str, required=True,
+                           help="Path to the source Model")
+    ir_parser.add_argument("-d", "--dest_model", type=str, required=True,
+                           help="Path to the destination Model")
+    ir_parser.add_argument("-s", "--scale", type=float, required=True,
+                           help="The Rescaling scale")
+    ir_parser.add_argument("-o", "--offset", type=float, required=True,
+                           help="The Rescaling offset")
+
     args = parser.parse_args()
 
     if args.action == "version":
@@ -194,7 +210,6 @@ def main():
         quantize_model(
             model_path=args.model,
             quant_config=args.quantization_config,
-            fold=args.fold,
             add_deq=args.no_deq,
             output_name=args.out_name
         )
@@ -215,3 +230,5 @@ def main():
         )
     elif args.action == "check":
         check_quantized_model(args.model)
+    elif args.action == "insert_rescaling":
+        insert_rescaling_and_save(args.model, args.dest_model, args.scale, args.offset)
