@@ -22,7 +22,7 @@ from keras.utils import conv_utils
 from .recorders import TensorRecorder
 from .quantizers import (WeightQuantizer, AlignedWeightQuantizer,
                          OutputQuantizer)
-from ..tensors import QTensor, FixedPoint, MAX_BUFFER_BITWIDTH
+from ..tensors import QTensor, QFloat, FixedPoint, MAX_BUFFER_BITWIDTH
 
 
 __all__ = ["PaddedConv2D", "QuantizedConv2D", "QuantizedConv2DTranspose"]
@@ -32,10 +32,10 @@ def apply_padding(inputs, strides, kernel_size, padding_value):
     """Apply "SAME" padding to the inputs
 
     Args:
-        inputs (tf.Tensor): the inputs tensor.
+        inputs (:obj:`QFloat`): the inputs tensor.
         strides (tuple): the strides tuple.
         kernel_size (int): the kernel size.
-        padding_value (tf.Tensor): the padding value to apply.
+        padding_value (:obj:`QFloat`): the padding value to apply.
 
     Returns:
         tf.Tensor: padded inputs.
@@ -119,10 +119,6 @@ class QuantizedConv2D(layers.Conv2D):
             type. If None, zero-padding is used. Defaults to None.
     """
 
-    # The padding_value frac_bits for the 'same' convolution type when we use
-    # a tf.Tensor for this parameter.
-    _PADDING_FRAC_BITS = 1
-
     def __init__(self, *args, padding_value=None, quant_config, **kwargs):
         super().__init__(*args, **kwargs)
         self.quant_config = quant_config
@@ -140,27 +136,22 @@ class QuantizedConv2D(layers.Conv2D):
         self.buffer_bitwidth = self.quant_config.get(
             "buffer_bitwidth", MAX_BUFFER_BITWIDTH) - 1
         assert self.buffer_bitwidth > 0, "The buffer_bitwidth must be a strictly positive integer."
-        if padding_value is not None:
+        if padding_value is None:
+            self.padding_value = None
+        else:
+            self.padding_value = float(padding_value)
             # Raise an error if the padding value is not a scalar
             if tf.size(padding_value) != 1:
                 raise ValueError(f"The padding value must be a scalar. Receives {padding_value}.")
-            padding_value = FixedPoint.quantize(padding_value,
-                                                self.buffer_bitwidth,
-                                                self._PADDING_FRAC_BITS)
-            padding_value = padding_value.promote(self.buffer_bitwidth)
-            # _padding_value is a private member because value controls are operated
-            # in the constructor.
+            # We quantize the padding_value with the same bitwidth as the weights
+            self.padding_value_quantizer = AlignedWeightQuantizer(self.weight_quantizer.bitwidth,
+                                                                  signed=True)
             # When a custom padding_value is given, self.padding is overwritten and 'SAME' padding
             # will be done explicitely in the call.
-            self._padding_value = padding_value
             self.padding = 'valid'
-        else:
-            self._padding_value = None
 
         # Add objects that will store the shift values.
         self.input_shift = TensorRecorder()
-        if self._padding_value is not None:
-            self.pad_shift = TensorRecorder()
 
     def call(self, inputs):
         # raise an error if the inputs are not QTensor or tf.Tensor
@@ -187,18 +178,21 @@ class QuantizedConv2D(layers.Conv2D):
         # Quantize the weights
         kernel = self.weight_quantizer(self.kernel)
 
-        # We need a custom padding for specifics padding values
-        if self._padding_value is not None:
-            # Set the same scale factor as inputs
-            padding_value, shift = self._padding_value.align(inputs, self.buffer_bitwidth)
-            self.pad_shift(shift)
+        if self.padding_value is not None:
+            # We need to align the padding value on the inputs, which is only supported for QFloat
+            # Note that this restriction is purely to reduce the cognitive and test cost: should
+            # we need at some point to support it, we could extend the AlignedWeightQuantizer or
+            # wrap the inputs in a QFloat of scale 1.
+            if not isinstance(inputs, QFloat):
+                raise ValueError("When using a non-zero padding value, the inputs must be QFloat.")
+            # Quantize and align padding_value on the inputs
+            padding_value = self.padding_value_quantizer(self.padding_value, inputs)
 
             # Note that we use the custom padding even when padding value is 0.
-            inputs_padded = apply_padding(inputs.values,
-                                          list(self.strides),
-                                          (kernel.shape[1], kernel.shape[0]),
-                                          padding_value.values)
-            inputs = FixedPoint(inputs_padded, inputs.value_bits, inputs.frac_bits)
+            inputs = apply_padding(inputs,
+                                   list(self.strides),
+                                   (kernel.shape[1], kernel.shape[0]),
+                                   padding_value)
 
         if isinstance(self.padding, str):
             tf_padding = self.padding.upper()
@@ -225,8 +219,8 @@ class QuantizedConv2D(layers.Conv2D):
     def get_config(self):
         config = super().get_config()
         config["quant_config"] = self.quant_config
-        if self._padding_value is not None:
-            config["padding_value"] = self._padding_value.to_float().numpy()
+        if self.padding_value is not None:
+            config["padding_value"] = self.padding_value
         return config
 
 
