@@ -17,7 +17,7 @@
 import tensorflow as tf
 import keras
 
-from ..tensors import FixedPoint, MAX_BUFFER_BITWIDTH
+from ..tensors import QTensor, FixedPoint, MAX_BUFFER_BITWIDTH
 from .recorders import TensorRecorder
 from .quantizers import (WeightQuantizer, OutputQuantizer,
                          AlignedWeightQuantizer)
@@ -55,9 +55,9 @@ class QuantizedDense(keras.layers.Dense):
         self.input_shift = TensorRecorder()
 
     def call(self, inputs):
-        # raise an error if the inputs are not FixedPoint or tf.Tensor
-        if not isinstance(inputs, (FixedPoint, tf.Tensor)):
-            raise TypeError(f"QuantizedDense only accepts FixedPoint or tf.Tensor\
+        # raise an error if the inputs are not QTensor or tf.Tensor
+        if not isinstance(inputs, (QTensor, tf.Tensor)):
+            raise TypeError(f"QuantizedDense only accepts QTensor or tf.Tensor\
                               inputs. Receives {type(inputs)} inputs.")
 
         # Quantize the weights
@@ -66,11 +66,15 @@ class QuantizedDense(keras.layers.Dense):
         if isinstance(inputs, tf.Tensor):
             # Assume the inputs are integer stored as float, which is the only tf.Tensor
             # inputs that are allowed
-            inputs = FixedPoint(inputs, 8, 0)
+            inputs = FixedPoint(inputs, 8, 0).promote(self.buffer_bitwidth)
 
-        # Expand the inputs to a higher bitwidth to avoid saturation and align them
-        inputs, shift = inputs.expand(self.buffer_bitwidth)
-        self.input_shift(shift)
+        if isinstance(inputs, FixedPoint):
+            # Expand the inputs to a higher bitwidth to avoid saturation and align them
+            inputs, shift = inputs.expand(self.buffer_bitwidth)
+            self.input_shift(shift)
+        else:
+            # Just promote the QFloat inputs to avoid a saturation
+            inputs = inputs.promote(self.buffer_bitwidth)
 
         outputs = tf.matmul(inputs, kernel)
 
