@@ -42,9 +42,10 @@ class Quantizer(Layer):
     """
 
     def __init__(self, bitwidth, signed=True, **kwargs):
-        if not isinstance(bitwidth, int) or bitwidth < 2:
+        min_bitwidth = 2 if signed else 1
+        if not isinstance(bitwidth, int) or bitwidth < min_bitwidth:
             raise ValueError(
-                f"Bitwidth should be an int >= 2, currently {bitwidth}")
+                f"Bitwidth should be an int >= {min_bitwidth}, currently {bitwidth}")
         self.bitwidth = bitwidth
         self.signed = signed
         self.value_bits = bitwidth - 1 if signed else bitwidth
