@@ -16,7 +16,6 @@
 # ******************************************************************************
 import tensorflow as tf
 
-from ...debugging import assert_equal
 from ...tensors import QTensor, QFloat, FixedPoint
 from ..recorders import FixedPointRecorder, QFloatRecorder
 from .quantizers import Quantizer
@@ -101,8 +100,6 @@ class WeightQuantizer(Quantizer):
             scales = QFloat.optimal_scales(ranges, self.value_bits)
             # Since we use the optimal quantization ranges [-int_max -1, int_max], the inner
             # FixedPoint can be quantized with exactly zero fractional bits
-            assert_equal(0., QFloat.max_frac_bits(self.value_bits, ranges, scales))
-            # Quantize the inputs projected in the optimal ranges
             qweights = QFloat.quantize(inputs, self.value_bits, scales, 0.)
         else:
             # Evaluate the maximum fractional bits we can use for the specified range
