@@ -18,7 +18,7 @@ import tensorflow as tf
 import keras
 
 from ...tensors import FixedPoint
-
+from ...debugging import assert_equal
 
 __all__ = ["QuantizedPermute"]
 
@@ -45,7 +45,7 @@ class QuantizedPermute(keras.layers.Permute):
             # Different fractional-bits are defined for the last axis, so
             # it must be preserved during the transposition
             last_axis = tf.rank(inputs.values) - 1
-            tf.assert_equal(self.dims[-1], last_axis)
+            assert_equal(self.dims[-1], last_axis)
         # Transpose only the values
         transposed_values = super().call(inputs.values)
         # Return a FixedPoint with the modified values
