@@ -22,7 +22,7 @@ from keras import Model
 
 from .utils import deep_clone_model, insert_layer, find_layer_config
 from .transforms import (align_rescaling, invert_batchnorm_pooling, fold_batchnorms,
-                         align_relu_max_value)
+                         align_relu_max_value, remove_zeropadding2d)
 from ..layers import (QuantizedDense, QuantizedLayerNormalization, QuantizedAddPositionEmbs,
                       QuantizedClassToken, QuantizedReLU, QuantizedAdd, QDropout,
                       QuantizedReshape, QuantizedAttention, QuantizedConv2D, QuantizedMaxPool2D,
@@ -31,7 +31,8 @@ from ..layers import (QuantizedDense, QuantizedLayerNormalization, QuantizedAddP
                       OutputQuantizer, WeightQuantizer, QuantizedConv2DTranspose,
                       QuantizedShiftmax, QuantizedSeparableConv2DTranspose,
                       QuantizedDepthwiseConv2D, QuantizedUnfoldPatches, QuantizedFoldPatches,
-                      QuantizedConcatenate, QuantizedRescaling)
+                      QuantizedConcatenate, QuantizedRescaling,
+                      QuantizedBatchNormalization)
 
 # Mapper to match float layer with its quantized version
 CUSTOM_QLAYERS = {
@@ -47,7 +48,8 @@ CUSTOM_QLAYERS = {
     "SeparableConv2DTranspose": QuantizedSeparableConv2DTranspose,
     "DepthwiseConv2D": QuantizedDepthwiseConv2D, "UnfoldPatches": QuantizedUnfoldPatches,
     "FoldPatches": QuantizedFoldPatches, "Concatenate": QuantizedConcatenate,
-    "Rescaling": QuantizedRescaling
+    "Rescaling": QuantizedRescaling,
+    "BatchNormalization": QuantizedBatchNormalization
 }
 # List of Quantizer layer's that do not have a float layer representation
 NO_FLOAT_CUSTOM_QLAYERS = [Dequantizer, OutputQuantizer, WeightQuantizer]
@@ -168,6 +170,12 @@ def quantize(model, q_config, add_dequantizer=True):
                         f"Receives '{config[arg]}'.")
                 config.pop(arg, None)
 
+        # Function to handle arguments that should be ignored, i.e. dropped,
+        # from config
+        def pop_ignored_args(class_type):
+            for arg in getattr(class_type, "ignored_args", []):
+                config.pop(arg, None)
+
         # Function that return a quantized layer given its float version
         def get_quantize_layer(layer, quantize_config={}):
             """Quantize float layer in three steps:
@@ -191,7 +199,9 @@ def quantize(model, q_config, add_dequantizer=True):
                 # If a Dequantizer is found, quantization must be stopped
                 quantization_stopped = isinstance(layer, Dequantizer)
 
-            # 2. Remove unsupported arguments
+            # 2.1 Remove ignored arguments
+            pop_ignored_args(qlayer)
+            # 2.2 Remove unsupported arguments
             pop_unsupported_args(qlayer)
 
             # 3. Instantiate quantized layer
@@ -227,6 +237,10 @@ def quantize(model, q_config, add_dequantizer=True):
     model = invert_batchnorm_pooling(model)
     model = fold_batchnorms(model)
 
+    # Remove unsupported ZeroPadding2D layers and replace them with 'same' padding convolution when
+    # possible
+    model = remove_zeropadding2d(model)
+
     # Align ReLU max_value to the maximum integer value the OutputQuantizer can use
     model = align_relu_max_value(model, q_config)
 
