@@ -243,10 +243,7 @@ def get_BN_less_model(model, map_prev_layer_to_bn):
                 config['output_layers'][index][0] = new_output_name
 
     # Reconstruct model from the config, using the cloned layers.
-    if isinstance(model, keras.Sequential):
-        return keras.Sequential.from_config(config)
-    else:
-        return keras.Model.from_config(config)
+    return model.from_config(config)
 
 
 def _compute_BN_folded_weights(target_layer, bn_layer):
