@@ -24,7 +24,6 @@ from copy import deepcopy
 from pathlib import Path
 
 import numpy as np
-import tensorflow_addons as tfa
 from keras.models import clone_model, load_model as kload_model, Model, Sequential
 from keras.layers import serialize, Layer, InputLayer, Rescaling
 
@@ -45,9 +44,6 @@ def load_model(model_path, custom_layers={}, compile_model=True):
     Returns:
         :class:`keras.models.Model`: the loaded model
     """
-    # Given that all layers were imported in __init__.py, they are registered.
-    # Therefore, we just need append GroupNormalization in the custom layers.
-    custom_layers.update({'GroupNormalization': tfa.layers.GroupNormalization})
     return kload_model(model_path, custom_objects=custom_layers, compile=compile_model)
 
 
