@@ -68,7 +68,7 @@ class FixedPoint(QTensor):
 
         This method evaluates the minimum number of integer bits required to cover
         the specified quantization ranges (this can be a negative number if the
-        ranges are strictly lower than zero).
+        ranges are strictly lower than 0.5).
         From that it deduces the rightmost fractional bit indices. This can also be a negative
         number if the ranges are higher than the biggest integer than can be represented with the
         specified value bits)
@@ -134,9 +134,7 @@ class FixedPoint(QTensor):
                 # The input does not need to be quantized
                 frac_bits = 0
             else:
-                # Evaluate integer bits
-                int_bits = ceil_log2(tf.abs(x))
-                frac_bits = tf.maximum(0, value_bits - int_bits)
+                frac_bits = FixedPoint.max_frac_bits(value_bits, tf.abs(x))
         # Project float into fixed-point representation space
         x_scaled = x * pow2(frac_bits)
         # Round or ceil to obtain integer values
