@@ -164,3 +164,73 @@ def fp_reduce_max(input_tensor: FixedPoint,
                                   name=name)
     # Return a new FixedPoint
     return FixedPoint(s_values, input_tensor.value_bits, input_tensor.frac_bits)
+
+
+@tf.experimental.dispatch_for_api(tf.math.multiply)
+def fp_fp_multiply(x: FixedPoint, y: FixedPoint, name=None):
+    """Returns an element-wise x * y.
+
+    Args:
+        x (:obj:`FixedPoint`): a FixedPoint
+        y (:obj:`FixedPoint`): a FixedPoint
+        name (str, optional): A name for the operation
+
+    Returns:
+        :obj:`FixedPoint`: an object with the same shape as x
+    """
+    return x * y
+
+
+@tf.experimental.dispatch_for_api(tf.math.multiply)
+def fp_qf_multiply(x: FixedPoint, y: QFloat, name=None):
+    """Returns an element-wise x * y.
+
+    Args:
+        x (:obj:`FixedPoint`): a FixedPoint
+        y (:obj:`QFloat`): a QFloat
+        name (str, optional): A name for the operation
+
+    Returns:
+        :obj:`QFloat`: an object with the same shape as x
+    """
+    # Multiply x by y inner FixedPoint
+    # To produce a per-tensor FixedPoint, x must be per-tensor
+    x.assert_per_tensor()
+    mul = tf.math.multiply(x, y.fp, name)
+    # Return a new QFloat with y scales
+    return QFloat(mul, y.scales)
+
+
+@tf.experimental.dispatch_for_api(tf.math.divide)
+def fp_fp_divide(x: FixedPoint, y: FixedPoint, name=None):
+    """Computes Python style division of `x` by `y`.
+
+    Args:
+        x (:obj:`FixedPoint`): the FixedPoint to divide
+        y (:obj:`FixedPoint`): the FixedPoint divisor
+        name (str, optional): A name for the operation
+
+    Returns:
+        :obj:`FixedPoint`: an object with the same shape as x
+    """
+    return x / y
+
+
+@tf.experimental.dispatch_for_api(tf.math.divide)
+def qf_fp_divide(x: QFloat, y: FixedPoint, name=None):
+    """Computes Python style division of `x` by `y`.
+
+    Args:
+        x (:obj:`QFloat`): the QFloat to divide
+        y (:obj:`FixedPoint`): the FixedPoint divisor
+        name (str, optional): A name for the operation
+
+    Returns:
+        :obj:`QFloat`: an object with the same shape as x
+    """
+    # Divide x inner FixedPoint by y
+    # To produce a per-tensor FixedPoint, y must be per-tensor
+    y.assert_per_tensor()
+    div = tf.math.divide(x.fp, y, name)
+    # Return a new QFloat with x scales
+    return QFloat(div, x.scales)
