@@ -17,7 +17,7 @@
 import tensorflow as tf
 from typing import List
 
-from ...debugging import assert_equal
+from ...debugging import assert_equal, assert_less_equal
 from .. import FixedPoint, QFloat
 
 
@@ -82,7 +82,7 @@ def fp_brodcast_to(input: FixedPoint, shape, name=None):
             type as `input`.
   """
     # Check first that the last dimension is unchanged
-    tf.assert_equal(input.shape[-1], shape[-1], message="To brodcast FixedPoint input,\
+    assert_equal(input.shape[-1], shape[-1], message="To brodcast FixedPoint input,\
                         last dimension should remain unchanged")
     output = tf.broadcast_to(input.values, shape, name)
     return FixedPoint(output, input.value_bits, input.frac_bits)
@@ -122,7 +122,7 @@ def fp_concat(values: List[FixedPoint], axis, name="concat"):
         :obj:`FixedPoint`: the concatenate output FixedPoint.
     """
     # For now we only support concatenation of one or two elements
-    tf.debugging.assert_less_equal(
+    assert_less_equal(
         len(values),
         2, f"We only support concatenation of one or two FixedPoint. \
            Receives {len(values)} tensors as input.")
@@ -131,9 +131,9 @@ def fp_concat(values: List[FixedPoint], axis, name="concat"):
         return FixedPoint(values[0].values, values[0].value_bits, values[0].frac_bits)
 
     # Only support inputs with the same value bits
-    tf.assert_equal(values[0].value_bits, values[1].value_bits, "We only support concatenation of "
-                    f"inputs with same value_bits. Receives {values[0].value_bits} and "
-                    f"{values[1].value_bits}.")
+    assert_equal(values[0].value_bits, values[1].value_bits, "We only support concatenation of "
+                 f"inputs with same value_bits. Receives {values[0].value_bits} and "
+                 f"{values[1].value_bits}.")
 
     # For now we don't support concatenation over last dimension
     rank_input = values[0].values.shape.ndims
@@ -147,7 +147,7 @@ def fp_concat(values: List[FixedPoint], axis, name="concat"):
     # When dim is not last dimension FixedPoint tensors to concatenate should have the same
     # fractional bits
     if not last_dim:
-        tf.assert_equal(values[0].frac_bits, values[1].frac_bits, message=f"the two\
+        assert_equal(values[0].frac_bits, values[1].frac_bits, message=f"The two\
                 FixedPoint must have the same frac_bits. Receives {values[0].frac_bits}\
                 and {values[1].frac_bits}")
         frac_bits_out = values[0].frac_bits
@@ -186,7 +186,7 @@ def qf_concat(values: List[QFloat], axis, name="concat"):
         return QFloat(values[0].fp, values[0].scales)
 
     # For now we only support concatenation of one or two elements
-    tf.assert_equal(
+    assert_equal(
         len(values),
         2, f"We only support concatenation of one or two QFloat. \
            Receives {len(values)} tensors as input.")
@@ -220,9 +220,9 @@ def qf_concat(values: List[QFloat], axis, name="concat"):
         output_scales = tf.concat([scales_a, scales_b], axis=-1, name=f"{name}_scales")
     else:
         # When concatenating on another axis, inputs must have the same scales
-        tf.assert_equal(values[0].scales, values[1].scales,
-                        "We only support concatenation of QFloat inputs with same scales."
-                        f"Receives {a.scales} and {b.scales}.")
+        assert_equal(values[0].scales, values[1].scales,
+                     "We only support concatenation of QFloat inputs with same scales."
+                     f"Receives {a.scales} and {b.scales}.")
         output_scales = a.scales
 
     return QFloat(output_fp, output_scales)
@@ -298,3 +298,61 @@ def fp_gather(params: FixedPoint, indices, validate_indices=None,
     # Create a new QTensor, gather the indices in a desired axis
     x_gather = tf.gather(params.values, indices, validate_indices, axis, batch_dims, name)
     return FixedPoint(x_gather, params.value_bits, params.frac_bits)
+
+
+@tf.experimental.dispatch_for_api(tf.pad)
+def fp_pad(tensor: FixedPoint,
+           paddings,
+           mode="CONSTANT",
+           constant_values: FixedPoint = None,
+           name=None):
+    """Pads a FixedPoint tensor with a mandatory FixedPoint padding value.
+
+    Args:
+        tensor (:obj:`FixedPoint`): the input FixedPoint.
+        paddings (:obj:`tensorflow.Tensor`): A `Tensor` of type `int32`.
+        mode (str): must be "CONSTANT".
+        constant_values (:obj:`FixedPoint`): the scalar pad value to use.
+        name (str): A name for the operation (optional).
+
+    Returns:
+        :obj:`FixedPoint`: a new FixedPoint with padding.
+    """
+    if mode != 'CONSTANT':
+        raise ValueError("When padding a FixedPoint, a constant padding value must be specified.")
+    # If the FixedPoint is per-axis, we could pad on any dimension except the last one
+    # but we only support per-tensor FixedPoint to limit cognitive and test costs.
+    tensor.assert_per_tensor()
+    assert_equal(tensor.frac_bits, constant_values.frac_bits,
+                 "Padding value is not aligned with the tensor.")
+    padded_values = tf.pad(tensor.values, paddings, mode, constant_values.values, name)
+    return FixedPoint(padded_values, tensor.value_bits, tensor.frac_bits)
+
+
+@tf.experimental.dispatch_for_api(tf.pad)
+def qf_pad(tensor: QFloat,
+           paddings,
+           mode="CONSTANT",
+           constant_values: QFloat = None,
+           name=None):
+    """Pads a QFloat tensor with a mandatory QFloat padding value.
+
+    Args:
+        tensor (:obj:`QFloat`): the input QFloat.
+        paddings (:obj:`tensorflow.Tensor`): A `Tensor` of type `int32`.
+        mode (str): must be "CONSTANT".
+        constant_values (:obj:`QFloat`): the scalar pad value to use.
+        name (str): A name for the operation (optional).
+
+    Returns:
+        :obj:`QFloat`: a new QFloat with padding.
+    """
+    if mode != 'CONSTANT':
+        raise ValueError("When padding a QFloat, a constant padding value must be specified.")
+    # If the QFloat is per-axis, we could pad on any dimension except the last one
+    # but we only support per-tensor QFloat to limit cognitive and test costs.
+    tensor.assert_per_tensor()
+    assert_equal(tensor.scales, constant_values.scales,
+                 "Padding value is not aligned with the tensor.")
+    padded_fp = tf.pad(tensor.fp, paddings, mode, constant_values.fp, name)
+    return QFloat(padded_fp, tensor.scales)
